@@ -36,7 +36,20 @@ namespace MonoDevelop.Database.Sql.MySql
 	{
 		public bool ShowCreateDatabaseDialog (IDbFactory factory)
 		{
-			return false;
+			MySqlCreateDatabaseDialog dialog = new MySqlCreateDatabaseDialog (factory);
+			int resp;
+			do {
+				resp = dialog.Run ();
+			} while (resp != (int)ResponseType.Cancel && 
+				    	     resp != (int)ResponseType.Ok && 
+				    		resp != (int)ResponseType.DeleteEvent);
+			dialog.Destroy ();
+			if (resp == (int)ResponseType.Ok)
+				return true;
+			else
+				return false;
+		
+			// return (RunDialog (new MySqlCreateDatabaseDialog (factory)));
 		}
 
 		public bool ShowAddConnectionDialog (IDbFactory factory)
@@ -45,18 +58,25 @@ namespace MonoDevelop.Database.Sql.MySql
 			return RunDialog (dlg);
 		}
 		
-		public bool ShowEditConnectionDialog (IDbFactory factory, DatabaseConnectionSettings settings)
+		public bool ShowEditConnectionDialog (IDbFactory factory, 
+		                                      DatabaseConnectionSettings settings, 
+		                                      out DatabaseConnectionSettings newSettings)
 		{
 			DatabaseConnectionSettingsDialog dlg = new DatabaseConnectionSettingsDialog (factory, settings);
-			return RunDialog (dlg);
+			bool result = RunDialog (dlg);
+			if (result)
+				newSettings = dlg.ConnectionSettings;
+			else
+				newSettings = null;
+			return result;
 		}
 
 		public bool ShowTableEditorDialog (IEditSchemaProvider schemaProvider, TableSchema table, bool create)
 		{
 			TableEditorSettings settings = new TableEditorSettings ();
+			settings.ConstraintSettings.CheckSettings.SupportsColumnConstraints = false;
 			TableEditorDialog dlg = new TableEditorDialog (schemaProvider, create, settings);
 			dlg.Initialize (table);
-
 			return RunDialog (dlg);
 		}
 
@@ -72,9 +92,9 @@ namespace MonoDevelop.Database.Sql.MySql
 		public bool ShowProcedureEditorDialog (IEditSchemaProvider schemaProvider, ProcedureSchema procedure, bool create)
 		{
 			ProcedureEditorSettings settings = new ProcedureEditorSettings ();
+			settings.ShowName = false;
 			ProcedureEditorDialog dlg = new ProcedureEditorDialog (schemaProvider, create, settings);
 			dlg.Initialize (procedure);
-
 			return RunDialog (dlg);
 		}
 
@@ -84,15 +104,25 @@ namespace MonoDevelop.Database.Sql.MySql
 		}
 
 		private bool RunDialog (Dialog dlg)
-		{
+			{
 			bool result = false;
+			// If the Preview Dialog is canceled, don't execute and don't close the Editor Dialog.
 			try {	
-				if (dlg.Run () == (int)ResponseType.Ok)
+				int resp;
+					do {
+						resp = dlg.Run ();
+				    } while (resp != (int)ResponseType.Cancel && 
+				    	     resp != (int)ResponseType.Ok && 
+				    		resp != (int)ResponseType.DeleteEvent);
+					
+				if (resp == (int)ResponseType.Ok)
 					result = true;
+				else
+					result = false;
 			} finally {
 				dlg.Destroy ();
 			}
 			return result;
 		}
 	}
-}
\ No newline at end of file
+}
